#!/bin/bash -e

cd ~/Downloads
for image in *ubuntu*.iso; do
    basename=${image%%.iso}
    uuid=$(uuidgen)
    cat > /tmp/kvm-config.xml << EOF
<domain type='kvm'>
<name>$basename</name>
<uuid>$uuid</uuid>
<memory>7864325</memory>
<currentMemory>7864325</currentMemory>
<vcpu>1</vcpu>
<os>
    <type arch='i686' machine='pc-1.0'>hvm</type>
    <boot dev='cdrom'/>
</os>
<features>
    <acpi/>
    <apic/>
    <pae/>
</features>
<clock offset='utc'/>
<on_poweroff>destroy</on_poweroff>
<on_reboot>restart</on_reboot>
<on_crash>restart</on_crash>
<devices>
    <emulator>/usr/bin/kvm</emulator>
    <disk type='file' device='cdrom'>
    <driver name='qemu' type='raw'/>
    <source file='/home-data/mh21/Downloads/$image'/>
    <target dev='hdc' bus='ide'/>
    <readonly/>
    <alias name='ide0-1-0'/>
    <address type='drive' controller='0' bus='1' unit='0'/>
    </disk>
    <controller type='ide' index='0'>
    <alias name='ide0'/>
    <address type='pci' domain='0x0000' bus='0x00' slot='0x01' function='0x1'/>
    </controller>
    <interface type='network'>
    <mac address='52:54:00:d6:1a:b7'/>
    <source network='default'/>
    <target dev='vnet0'/>
    <model type='virtio'/>
    <alias name='net0'/>
    <address type='pci' domain='0x0000' bus='0x00' slot='0x03' function='0x0'/>
    </interface>
    <serial type='pty'>
    <source path='/dev/pts/1'/>
    <target port='0'/>
    <alias name='serial0'/>
    </serial>
    <console type='pty' tty='/dev/pts/1'>
    <source path='/dev/pts/1'/>
    <target type='serial' port='0'/>
    <alias name='serial0'/>
    </console>
    <input type='mouse' bus='ps2'/>
    <graphics type='vnc' port='5900' autoport='yes'/>
    <sound model='ich6'>
    <alias name='sound0'/>
    <address type='pci' domain='0x0000' bus='0x00' slot='0x04' function='0x0'/>
    </sound>
    <video>
    <model type='vmvga' vram='9216' heads='1'/>
    <alias name='video0'/>
    <address type='pci' domain='0x0000' bus='0x00' slot='0x02' function='0x0'/>
    </video>
    <memballoon model='virtio'>
    <alias name='balloon0'/>
    <address type='pci' domain='0x0000' bus='0x00' slot='0x05' function='0x0'/>
    </memballoon>
</devices>
</domain>
EOF

sendkeys() {
    a=
    while (( "$#" )); do
        a="$a KEY_$1"
        shift
    done
    virsh send-key $basename $a > /dev/null
    sleep 1
}

    echo Creating and starting machine $basename...
    virsh create /tmp/kvm-config.xml
    sleep 2
    sendkeys SPACE
    sendkeys F2 ENTER ENTER

    sleep 30

    if [[ $basename == kubuntu* ]]; then
        echo Skipping welcome message...
        sendkeys TAB
        sendkeys TAB
        sendkeys SPACE > /dev/null

        sleep 20

        echo Loading terminal...
        sendkeys LEFTALT F1
        sendkeys T E R M I N A L
        sleep 2
        sendkeys BACKSPACE
        sleep 2
        sendkeys ENTER
    elif [[ $basename == ubuntu* ]]; then
        echo Loading terminal...
        sendkeys LEFTMETA
        sendkeys T E R M
        sleep 1
        sendkeys ENTER
    else
        echo Loading terminal...
        sendkeys LEFTALT F2
        sendkeys X MINUS T E R M I N A L
        sendkeys MINUS E M U L A T O R
        sleep 1
        sendkeys ENTER
    fi

    sleep 2

    echo Installing...
    sendkeys W G E T SPACE
    sendkeys M H 2 1 DOT D E
    sendkeys SLASH I M SPACE
    sendkeys MINUS LEFTSHIFT O SPACE
    sendkeys MINUS LEFTSHIFT BACKSLASH
    sendkeys S H SPACE MINUS ENTER

    echo Hit enter when finished...
    read

    virsh screenshot $basename
    virsh suspend $basename
done
